@@ -25,6 +25,20 @@ ALLOW_NO_GIT_SUBCOMMAND = ["login", "qa", "aggregator"]
 ALLOW_NO_HOME_SUBCOMMAND = ["login", "qa", "aggregator"]
 
 
+def maybe_inject_truststore() -> None:
+    """
+    Injects the truststore package into the system ssl store, to fix verficiation certificate issues when using warp.
+    """
+    if sys.version_info >= (3, 10):
+        import truststore
+
+        truststore.inject_into_ssl()
+    else:
+        logger.warning(
+            "Your python version is older than 3.10 and doesn't support the truststore package. You might experience issues with certificate verification when connected to the warp VPN.\nPlease update to python 3.10 or newer"
+        )
+
+
 def fetch_latest_version() -> Optional[pkg_resources.packaging.version.Version]:
     """
     Fetches the latest version of suite-py as a pkg_resources parsed version
@@ -85,6 +99,7 @@ def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
 @click.option("-v", "--verbose", count=True)
 @click.pass_context
 def main(ctx, project, timeout, verbose):
+    maybe_inject_truststore()
     upgrade_suite_py_if_needed(break_on_missing_package=False)
     print(f"v{__version__}")
 
@@ -175,7 +190,7 @@ def cli_create_branch(obj, card):
 def cli_lock_project(obj, environment):
     from suite_py.commands.project_lock import ProjectLock
 
-    ProjectLock(obj["project"], environment, "lock", obj["config"]).run()
+    ProjectLock(obj["project"], environment, "lock", obj["config"], obj["tokens"]).run()
 
 
 @main.command("unlock", help="Unlock project on staging or prod")
@@ -186,7 +201,9 @@ def cli_lock_project(obj, environment):
 def cli_unlock_project(obj, environment):
     from suite_py.commands.project_lock import ProjectLock
 
-    ProjectLock(obj["project"], environment, "unlock", obj["config"]).run()
+    ProjectLock(
+        obj["project"], environment, "unlock", obj["config"], obj["tokens"]
+    ).run()
 
 
 @main.command("open-pr", help="Open a PR on GitHub")
@@ -558,3 +575,11 @@ def cli_run_batch_job(obj, environment, cpu_request, memory_request):
         cpu_request,
         memory_request,
     ).run()
+
+
+@main.command("set-token", help="Create or update a service token")
+@click.pass_obj
+def cli_set_token(obj):
+    from suite_py.commands.set_token import SetToken
+
+    SetToken(obj["tokens"]).run()
