@@ -6,7 +6,7 @@ import requests
 
 from suite_py.lib import logger
 from suite_py.lib.handler import prompt_utils
-from suite_py.lib.handler.git_handler import GitHandler
+from suite_py.lib.handler.git_handler import GitHandler, is_branch_name_valid
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 
@@ -94,15 +94,6 @@ class CreateBranch:
             return []
 
     def _checkout_branch(self, issue):
-        branch_name = prompt_utils.ask_questions_input(
-            "Enter branch name: ",
-            re.sub(
-                r'([\s\\.,~\^:\(\)\[\]\<\>"\'?\#]|[^\x00-\x7F]|[0-9])+',
-                "-",
-                issue["summary"],
-            ).lower(),
-        )
-
         default_parent_branch_name = self._config.user.get(
             "default_parent_branch", self._git.current_branch_name()
         )
@@ -111,10 +102,26 @@ class CreateBranch:
             "Insert initial branch: ", default_parent_branch_name
         )
 
-        branch_type = issue["Type"].lower().replace(" ", "-")
+        full_branch_name = ""
+        branch_name = _normalize_git_ref_segment(issue["summary"])
+        branch_type = _normalize_git_ref_segment(issue["Type"])
 
-        branch_name = f"{issue['idReadable']}/{branch_type}/{branch_name}"
+        while True:
+            branch_name = str(
+                prompt_utils.ask_questions_input("Enter branch name: ", branch_name)
+            )
+
+            full_branch_name = f"{issue['idReadable']}/{branch_type}/{branch_name}"
+            if is_branch_name_valid(full_branch_name):
+                break
+
+            logger.error(f"Invalid branch name: {full_branch_name}. Try again?")
 
         self._git.checkout(parent_branch_name)
 
-        self._git.checkout(branch_name, new=True)
+        self._git.checkout(full_branch_name, new=True)
+
+
+# Normalize a string into a valid segment(ie. the part of the branch name between the /)
+def _normalize_git_ref_segment(summary):
+    return re.sub(r"[^A-Za-z0-9]+", "-", summary).lower().strip("-")
