@@ -1,6 +1,5 @@
 import base64
 import hashlib
-import json
 import logging
 import secrets
 import sys
@@ -14,7 +13,6 @@ from flask import Flask, render_template, request
 from werkzeug.serving import make_server
 
 from suite_py.lib import logger
-from suite_py.lib.handler.qainit_handler import QainitHandler as qainit
 
 # Global vars for comunication between flask thread and main cli function
 received_callback = None
@@ -71,11 +69,7 @@ class Login:
     def __init__(self, config):
 
         try:
-            if (
-                not config.auth0["client_id"]
-                or not config.auth0["tenant"]
-                or not config.qainit["profile"]
-            ):
+            if not config.okta["client_id"] or not config.okta["base_url"]:
                 self.usage()
                 sys.exit(-1)
         except AttributeError:
@@ -83,11 +77,9 @@ class Login:
             sys.exit(-1)
 
         self._config = config
-        self.auth0_client_id = config.auth0["client_id"]
-        self.auth0_tenant = config.auth0["tenant"]
-        self.auth0_scope = "openid profile email " + " ".join(
-            qainit.scope_mapping[config.qainit["profile"]]
-        )
+        self.okta_client_id = config.okta["client_id"]
+        self.base_url = config.okta["base_url"]
+        self.okta_scope = "openid"
         self.redirect_uri = "http://127.0.0.1:5000/callback"
 
     def usage(self):
@@ -96,7 +88,7 @@ class Login:
             "please check docs: https://github.com/primait/suite_py/blob/master/README.md"
         )
 
-    def auth0_url_encode(self, byte_data):
+    def url_encode_no_padding(self, byte_data):
         """
         Safe encoding handles + and /, and also replace = with nothing
         :param byte_data:
@@ -105,26 +97,25 @@ class Login:
         return base64.urlsafe_b64encode(byte_data).decode("utf-8").replace("=", "")
 
     def generate_challenge(self, a_verifier):
-        return self.auth0_url_encode(hashlib.sha256(a_verifier.encode()).digest())
+        return self.url_encode_no_padding(hashlib.sha256(a_verifier.encode()).digest())
 
     def run(self):
         global received_callback
 
         # from https://auth0.com/docs/flows/add-login-using-the-authorization-code-flow-with-pkce
         # Step1: Create code verifier: Generate a code_verifier that will be sent to Auth0 to request tokens.
-        verifier = self.auth0_url_encode(secrets.token_bytes(32))
+        verifier = self.url_encode_no_padding(secrets.token_bytes(32))
         # Step2: Create code challenge: Generate a code_challenge from the code_verifier that will be sent to Auth0 to request an authorization_code.
         challenge = self.generate_challenge(verifier)
-        state = self.auth0_url_encode(secrets.token_bytes(32))
-        client_id = self.auth0_client_id
-        tenant = self.auth0_tenant
-        scope = self.auth0_scope
+        state = self.url_encode_no_padding(secrets.token_bytes(32))
+        client_id = self.okta_client_id
+        base_url = self.base_url
+        scope = self.okta_scope
         redirect_uri = self.redirect_uri
         #
         # We generate a nonce (state) that is used to protect against attackers invoking the callback
-        base_url = f"https://{tenant}.auth0.com/authorize?"
+        url = f"{base_url}/authorize?"
         url_parameters = {
-            "audience": "qainit",
             "scope": scope,
             "response_type": "code",
             "redirect_uri": redirect_uri,
@@ -133,7 +124,7 @@ class Login:
             "code_challenge_method": "S256",
             "state": state,
         }
-        url = base_url + urllib.parse.urlencode(url_parameters)
+        url = url + urllib.parse.urlencode(url_parameters)
 
         # Step3: Authorize user: Request the user's authorization and redirect back to your app with an authorization_code.
         # Open the browser window to the login url
@@ -162,24 +153,26 @@ class Login:
             sys.exit(1)
 
         # Step4: Request tokens: Exchange your authorization_code and code_verifier for tokens.
-        url = f"https://{tenant}.auth0.com/oauth/token"
-        headers = {"Content-Type": "application/json"}
+        url = f"{base_url}/token"
+        headers = {
+            "content-type": "application/x-www-form-urlencoded",
+            "Accept": "application/json",
+        }
         body = {
             "grant_type": "authorization_code",
             "client_id": client_id,
             "code_verifier": verifier,
             "code": code,
-            "audience": "https://prima-it-staging.eu.auth0.com/api/v2/",
             "redirect_uri": redirect_uri,
         }
         # pylint: disable-next=missing-timeout
-        r = requests.post(url, headers=headers, data=json.dumps(body))
+        r = requests.post(url, headers=headers, data=body)
         data = r.json()
         logger.debug(data)
-        if "access_token" in data:
-            token = str(data["access_token"])
+        if "id_token" in data:
+            token = str(data["id_token"])
         else:
-            logger.error("access_token not found in auth0 response")
+            logger.error("id_token not found in okta response")
             sys.exit(1)
         logger.info("login succeded")
-        self._config.put_cache(f"{tenant}_auth0_token", token)
+        self._config.put_cache(f"{base_url}_token", token)
