@@ -234,11 +234,9 @@ class Release:
                         builds.append(b)
 
             if not builds:
-                # may end up here if there isn't any successfull build for latest 10 tags
-                logger.error(
-                    "An error has occured retrieving current version during rollback.\nPlease ask #team-platform-operations for help."
+                raise Exception(
+                    "Perhaps there were not any successful builds for latest 10 tags?"
                 )
-                sys.exit(255)
 
             # get latest build using build number as key
             current_build = max(builds, key=lambda x: x["number"])
@@ -253,9 +251,9 @@ class Release:
             logger.info(f"Current version for country {country}: {v}")
 
             return v
-        except Exception:
+        except Exception as e:
             logger.error(
-                "An error has occured retrieving current version during rollback.\nPlease ask #team-platform-operations for help."
+                f"An error has occurred retrieving current version during rollback. {e}\nPlease ask #team-platform-operations for help."
             )
             sys.exit(255)
 
