@@ -118,9 +118,13 @@ class DroneHandler:
                 headers={"Authorization": f"Bearer {self._token}"},
             ).json()
 
-            return builds
         except Exception:
-            return []
+            builds = []
+
+        if isinstance(builds, dict) and builds.get("message") == "Unauthorized":
+            raise Exception("Drone API Error: Unauthorized - run suite-py check")
+
+        return builds
 
     def get_builds_from_branch(self, branch):
         try:
