@@ -358,3 +358,13 @@ def get_commit_logs(base_branch):
     ]
 
     return commits_list
+
+
+def is_branch_name_valid(branch_name):
+    result = subprocess.run(
+        ["git", "check-ref-format", "--branch", branch_name],
+        capture_output=True,
+        check=False,
+    )
+
+    return result.returncode == 0
